@@ -73,7 +73,7 @@ class Form(object):
 
     def __init__(self, config, item=None, dbsession=None, translate=None,
                  change_page_callback={}, renderers={}, request=None,
-                 csrf_token=None, eval_url=None):
+                 csrf_token=None, eval_url=None, url_prefix=""):
         """Initialize the form with ``Form`` configuration instance and
         optional an SQLAlchemy mapped object.
 
@@ -99,17 +99,18 @@ class Form(object):
         The return Value is a JSON response with success attribute set
         depending on the result of the evaluation and the error message in
         the data attribute in case the evaluation fails.
+        :url_prefix: Prefix which can be used for all URL in the form.
         """
         self._config = config
         self._item = item
         self._dbsession = dbsession
         self._request = request
         self._csrf_token = csrf_token
-        if request:
-            base_url = request.application_url
-            self._eval_url = base_url + eval_url
-        else:
-            self._eval_url = eval_url
+        self._url_prefix = url_prefix
+        self._eval_url = eval_url
+        if self._url_prefix:
+            self._eval_url = self._url_prefix + self._eval_url
+
         if translate:
             self._translate = translate
         else:
